RandomState

Struct RandomState 

1.76.0 ยท Source
pub struct RandomState { /* private fields */ }
RandomState is the default state for HashMap types.

A particular instance RandomState will create the same instances of Hasher, but the hashers created by two different RandomState instances are unlikely to produce the same result for the same values.

Examples

use std::collections::HashMap;
use std::hash::RandomState;

let s = RandomState::new();
let mut map = HashMap::with_hasher(s);
map.insert(1, 2);

Implementations

Source

impl RandomState

1.7.0 ยท Source

pub fn new() -> RandomState

Constructs a new RandomState that is initialized with random keys.

Examples
use std::hash::RandomState;

let s = RandomState::new();